import { getCSSDataDocumentation } from '../utils/get-css-data-documentation.mjs';
import { generateCSS, Layer, isCoreRule } from '@master/css';
import cssDataProvider from '../utils/css-data-provider.mjs';
import getUtilityInfo from '../utils/get-utility-info.mjs';

function inspectSyntax(document, position) {
    const classPosition = this.getClassPosition(document, position);
    if (!classPosition) return;
    const { token } = classPosition;
    const range = {
        start: document.positionAt(classPosition.range.start),
        end: document.positionAt(classPosition.range.end)
    };
    const styleClasses = this.css.styles[token];
    if (styleClasses) {
        const documentation = getCSSDataDocumentation({}, {
            generatedCSS: generateCSS([
                token
            ], this.css),
            docs: 'styles'
        });
        if (documentation) {
            return {
                contents: {
                    kind: documentation.kind,
                    value: `(style) ` + styleClasses.join(' ') + '\n' + documentation.value
                }
            };
        }
    } else {
        const rules = this.css.generate(token);
        const rule = rules[0];
        if (rule) {
            if (rule.layer === Layer.Utility) {
                const { data, docs } = getUtilityInfo(rule.RegisteredRule, this.css);
                const documentation = getCSSDataDocumentation(data, {
                    generatedCSS: generateCSS([
                        token
                    ], this.css),
                    docs
                });
                if (documentation) {
                    return {
                        contents: documentation,
                        range
                    };
                }
            } else {
                const nativeProperties = cssDataProvider.provideProperties();
                const nativeCSSPropertyData = nativeProperties.find(({ name })=>name === rule.id);
                const documentation = getCSSDataDocumentation(nativeCSSPropertyData, {
                    generatedCSS: generateCSS([
                        token
                    ], this.css),
                    docs: isCoreRule(rule.id) && rule.id
                });
                if (documentation) {
                    return {
                        contents: documentation,
                        range
                    };
                }
            }
        }
    }
}

export { inspectSyntax as default };
