'use strict';

var beautifyCss = require('./beautify-css.cjs');
var css = require('@master/css');

function getCSSDataDocumentation(data, additional) {
    const values = [];
    const references = data?.references ? [
        ...data.references
    ] : [];
    if (data?.status) {
        values.push(getEntryStatus(data.status));
    }
    if (additional?.generatedCSS) {
        values.push('```css\n' + beautifyCss(additional.generatedCSS) + '\n```');
    }
    if (data?.description) if (typeof data.description === 'string') {
        values.push(textToMarkedString(data.description));
    } else {
        values.push(data.description.kind === 'markdown' ? data.description.value : textToMarkedString(data.description.value));
    }
    const browserLabel = getBrowserLabel(data?.browsers);
    if (browserLabel) {
        values.push('(' + textToMarkedString(browserLabel) + ')');
    }
    if (data && 'syntax' in data && data.syntax) {
        values.push(`Syntax: ${textToMarkedString(data.syntax)}`);
    }
    // todo: can i use
    if (additional?.docs) {
        references.unshift({
            name: 'Master CSS',
            url: new URL(`/docs/${additional.docs}`, css.OFFICIAL_URL).href
        });
    }
    if (references.length) {
        values.push(references.map((r)=>{
            return `[${r.name}](${r.url})`;
        }).join(' | '));
    }
    return values?.length ? {
        kind: 'markdown',
        value: values.join('\n\n')
    } : undefined;
}
const browserNames = {
    E: 'Edge',
    FF: 'Firefox',
    S: 'Safari',
    C: 'Chrome',
    IE: 'IE',
    O: 'Opera'
};
function getEntryStatus(status) {
    switch(status){
        case 'experimental':
            return '⚠️ Property is experimental. Be cautious when using it.️\n\n';
        case 'nonstandard':
            return '🚨️ Property is nonstandard. Avoid using it.\n\n';
        case 'obsolete':
            return '🚨️️️ Property is obsolete. Avoid using it.\n\n';
        default:
            return '';
    }
}
function textToMarkedString(text) {
    text = text.replace(/[\\`*_{}[\]()#+\-.!]/g, '\\$&') // escape markdown syntax tokens: http://daringfireball.net/projects/markdown/syntax#backslash
    ;
    return text.replace(/</g, '&lt;').replace(/>/g, '&gt;');
}
function getBrowserLabel(browsers = []) {
    if (browsers.length === 0) {
        return null;
    }
    return browsers.map((b)=>{
        let value = '';
        const matches = b.match(/([A-Z]+)(\d+)?/) ?? '';
        const name = matches[1];
        const version = matches[2];
        if (name in browserNames) {
            value += browserNames[name];
        }
        if (version) {
            value += ' ' + version;
        }
        return value;
    }).join(', ');
}

exports.getCSSDataDocumentation = getCSSDataDocumentation;
