'use strict';

var css = require('@master/css');
var cssDataProvider = require('./css-data-provider.cjs');
var vscodeLanguageserverProtocol = require('vscode-languageserver-protocol');
var sortCompletionItems = require('./sort-completion-items.cjs');
var getCssDataDocumentation = require('./get-css-data-documentation.cjs');

const kind = vscodeLanguageserverProtocol.CompletionItemKind.Function;
function getPseudoClassCompletionItems(css$1 = new css.MasterCSS(), syntax) {
    const pseudoClassDataList = cssDataProvider.providePseudoClasses().filter((data)=>{
        // exclude @page pseudo-classes
        if ([
            ':first',
            ':left',
            ':right',
            ':blank'
        ].includes(data.name)) return false;
        return true;
    });
    const completionItems = pseudoClassDataList.map((data)=>{
        // fix https://github.com/microsoft/vscode-custom-data/issues/78
        const name = /:(?:dir|has|is|nth-col|where)/.test(data.name) ? data.name + '()' : data.name;
        let sortText = name.startsWith(':-') ? 'yyyy' + name.slice(2) : 'yy' + name.replace(/^:/, '');
        if (sortText.endsWith('()')) sortText = 'y' + sortText;
        return {
            label: name,
            sortText,
            documentation: getCssDataDocumentation.getCSSDataDocumentation(data, {
                generatedCSS: css.generateCSS([
                    syntax + name.slice(1)
                ], css$1),
                docs: 'selectors'
            }),
            kind,
            data
        };
    });
    for(const selectorName in css$1.config.selectors){
        if (selectorName.startsWith('::')) continue;
        const selectorValue = css$1.config.selectors[selectorName];
        const name = selectorName.endsWith('(') ? selectorName + ')' : selectorName;
        const value = typeof selectorValue === 'string' ? selectorValue.endsWith('(') ? selectorValue + ')' : selectorValue : selectorValue;
        const data = pseudoClassDataList.find((data)=>typeof value === 'string' ? value.startsWith(data.name) : false);
        let sortText = name.startsWith(':-') ? 'yyyy' + name.slice(2) : 'yy' + name.replace(/^:/, '');
        if (sortText.endsWith('()')) sortText = 'y' + sortText;
        const completionItem = {
            label: name,
            documentation: getCssDataDocumentation.getCSSDataDocumentation(data, {
                generatedCSS: css.generateCSS([
                    syntax + name.slice(1)
                ], css$1),
                docs: 'selectors'
            }),
            sortText,
            kind,
            detail: String(value),
            data
        };
        completionItems.push(completionItem);
    }
    return sortCompletionItems(completionItems);
}

module.exports = getPseudoClassCompletionItems;
